!-----------------------------------------------------------------------------
! Magic and Fight System --- damage system
! For INFORM compiler and Z-Machine text based Adventure games
!-----------------------------------------------------------------------------
!  Author: Giancarlo Niccolai
!  Version: 1.3
!  Last Revised: 2002-11-24
!  Contact author at:
!  Feel free to use and distribute this file, but please report me if
!  you intend to change it (in better), so we can upgrade together
!
!  Released under GPL 2.0, or any later version at your will
!
!-----------------------------------------------------------------------------
!
! Every object or character which could be damaged must
! have a "damage" routine, with parameters:
!  - the amount of damage
!  - the source of the the damage (which is the spell,
!    normally).
! So the target can be resistant to certain damage
! sources. The target may also test if the source is from a certain
! class by refering to the "sender" operator; in fact, the sender of the
! damage message is also the source. A Fireball spell and a Flame Thrower
! will cause both fire type damage, but hopefully they will be of two
! different classes: the operator 'sender ofclass' will indicate which fire
! is generated from the spell, and which from a war weapon.
!------------------------------------------------------------------------------

Ifndef damage;
Property damage;				!used also as Library flag

Constant DMG_GENERIC 0;			! The caller don't pass it to the target
Constant DMG_MAGIC 1;			! Pure magic source
Constant DMG_FIRE 2;			! Fire damage
Constant DMG_ELECTRICITY 4;	! High voltage!
Constant DMG_ICE 8;			! Cold damage
Constant DMG_ACID 16;			! Acid damage
Constant DMG_POISON 32;		! Poison
Constant DMG_CUTWEAPON 64;		! Swordlike damage
Constant DMG_HITWEAPON 128;		! HIT DAMAGE
Constant DMG_PSIONIC 256;		! Mental damage
Constant DMG_FATIGUE 512;		! Stress damage
Constant DMG_LIGHT 1024;			! Wounded by light bringing weapons.
Constant DMG_UNDEAD 2048;		! Wounded by UNDEAD Creatures
Constant DMG_PARALYSE 4096;		! Paralyzing damage
Constant DMG_FIREWEAPON 8192;	! Gunshot etc.
Constant DMG_BAREHANDS 16384;	! Attacking using bare ands and the like
!
! Verify how much damage should affect the target
! CheckDamage( dmg, source_type, immunity );
!
[CheckDamage par_dmg par_src par_imm v;
	v= par_src & par_imm;
	if ( v == 0 ) return par_dmg;
	if ( v == par_src ) return 0;
	return par_dmg/2;
];

Endif;
! end of MFS_Damage.h
