!-----------------------------------------------------------------------------
! Magic And Fight System --- Some global definitions....
! For INFORM compiler and Z-Machine text based Adventure games
!-----------------------------------------------------------------------------
!  Author: Giancarlo Niccolai
!
!  Contact author at: antispam@niccolai.ws
!  Feel free to use and distribute this file, but please report me if
!  you intend to change it (in better), so we can upgrade together
!
!  Released under GPL 2.0, or any later version at your will
!  $Id: MFS_Global.h,v 1.6 2003/10/26 01:29:21 gian Exp $
!-----------------------------------------------------------------------------
! Some useful global definitions
!-----------------------------------------------------------------------------

Ifndef GlobalValue;

Global the_spell;
Global the_object;

!-----------------------------------------------------------------------------
! This functions sums up all the properties (named prop) found in an object
! (pobj). If the test routine is given, the property is summed only if the
! test routine is true.
! Exhample:
!
! AttackBonus = GlobalValue( player, attack, giving_bonus );
!
! will return the sum of all the attack bonuses given by objects in the player,
! but only if their giving_bonus routines evaluates that the object CAN provide
! the bonus, i.e. a worn weapon or ring.
!
[GlobalValue pobj prop test obj val;
   val = 0;
   objectloop(obj in pobj && obj provides prop)
      if (test ~= nothing && obj provides test) {
         if (obj.test())
            val = val + obj.prop;
      }
      else
         val = val + obj.prop;
   if (pobj provides prop) {
      obj = pobj;
      if (test ~= nothing && obj provides test) {
         if (obj.test())
            val = val + obj.prop;
      }
      else
         val = val + obj.prop;
   }
   return val;
];

!-------------------------------------------
! Find the room where an object lies
!
[RoomOf obj;
   while (parent(obj) ~= nothing) obj = parent(obj);
   if (obj == thedark) obj = real_location;
   return obj;
];

!-------------------------------------------------------------------
! Describe bonus givers, weapons and armors
!

[DescBonusGiver obj cand;

   if (obj ofclass Weapon && obj provides max_damage && obj provides min_damage) {
      print "^",(The) obj;
      print " pu@`o causare un danno fra ", ( number ) obj.min_damage, " e ",
         (number) obj.max_damage, " punti vita";
      cand = 1;
   }
   else if ( obj provides max_damage && obj provides min_damage && obj.max_damage > 0 ) {
      print " aumenta il danno che puoi causare da un minimo di ", ( number ) obj.min_damage,
         " ad un massimo di ", (number) obj.max_damage, " punti vita";
      cand = 1;
   }

   if (obj provides attack && obj.attack > 0 ) {
      if (cand == 1)
         print ". Usando", (itorthem) obj;

      print ", il tuo attacco migliora";

      print " di ", (number) obj.attack, " punt", (numm) obj.attack;
      cand = 2;
   }

   if (obj provides defense && obj.defense > 0) {
      switch (cand) {
         0: print " migliora la tua difesa ";
         1:print ". Usando", (itorthem) obj," la tua difesa migliora";
         2:print ", e la tua difesa viene aumentata";
      }

      print " di ", (number) obj.defense, " punt", (numm) obj.defense;
      cand = 3;
   }

   if (obj provides armor && obj.armor > 0) {
      switch (cand) {
         0: print " migliora la tua armatura";
         1:print ". Usando", (itorthem) obj," la tua armatura migliora";
         2, 3:print ". ", (The) obj, " migliora anche la tua armatura";
      }

      print " di ", (number) obj.armor, " punt", (numm) obj.armor;

      cand = 4;
   }

   if (obj provides base_damage && obj.base_damage > 0) {
      switch (cand) {
         0: print " ti d@`a";
         1:print ". Usando" , (itorthem) obj,"procurerai ";
         2,3:print ". ", (The) obj, " ti dar@`a";
         4:print ", e procurerai" ;
      }

      print " ", (number) obj.base_damage, " punt",
            (numm) obj.base_damage;
      print " in pi@`u di danno base";

      cand = 5;
   }

   if (obj provides initiative && obj.initiative > 0) {
      switch (cand) {
         0: print " ti conceder@`a";
         1:print ". Inoltre, guadagnareai";
         2,3:print ". ", (The) obj, " ti dar@`a anche";
         4:print ", ed avrai" ;
         5:print ". In fine, questo oggetto ti dar@`a";
      }

      print " ", (number) obj.initiative, " punt", (numm) obj.initiative;
      print " di bonus sull'iniziativa in combattimento";
      cand = cand + 1;
   }
   if ( cand > 0 ) print ".^";

   !magic
   if ( (obj provides power_bonus && obj.power_bonus > 0) ||
      (obj provides cost_bonus && obj.cost_bonus > 0) ||
      (obj provides time_bonus && obj.time_bonus > 0) ) {
      if ( cand )
         print "Per quanto ", (string) random("riguarda","concerne","attiene a"),
            "i poteri magici ", (the) obj, " pu@`o";
      else
         print (The) obj, " pu@`o";
      cand = 0;

      if ( obj provides power_bonus && obj.power_bonus > 0 ) {
         print " aumentare il tuo potere di ";
         if ( obj.power_bonus == 1 )
            print "un";
         else
            print (number) obj.power_bonus;
         print " punt", (numm) obj.power_bonus;
         cand = cand + 1;
      }

      if (obj provides cost_bonus && obj.cost_bonus > 0) {
         if (cand )
            if (obj provides time_bonus && obj.time_bonus > 0)
               print ",";
            else
               print "e";
         print " diminuire il costo degli incantesimi di ";
         if ( obj.cost_bonus == 1 )
            print "un";
         else
            print (number) obj.cost_bonus;
         print " punt", (numm) obj.cost_bonus;
         cand = cand + 1;
      }

      if (obj provides time_bonus && obj.time_bonus > 0) {
         if (cand )
            print " e ";
         print " ridurre il tempo richiesto per il lancio di ";
         if ( obj.time_bonus == 1 )
            print "un";
         else
            print (number) obj.time_bonus;

         print " turn",(numm) obj.time_bonus;
         cand = cand + 1;
      }
      print ".^";
   }

];

!------------------------------------------------------------------
! Stampa il genere ed il numero di X. Troppo comodo per non avere
! un nome pi breve!
!
[gan x;
   print (genderandnumber) x;
];


!------------------------------------------------------------------
! Prints a string in raw internal representation format
!
[ByteArray x pos;
   pos = 0;
   while ( pos < x-->0 ) {
      print (char) x->(pos+2);
      pos++;
   }
];

!------------------------------------------------------------------
! Prints a word in a string in raw internal representation format
!
[ByteWord x pos;
   pos = 0;
   while ( x->pos && x->pos ~= $20) {
      print (char) x->pos;
      pos++;
   }
];

!------------------------------------------------------------------
! Print a notice
!

[Notice str;
   print "^[";
   style bold;
   print "Nota";
   style roman;
   print ": ", (string) str, "]^";
];

Endif;
! end of MFS_Global.h
